==> skeleton-0.9.24.tar.gz: lib/skeleton.dart <==
import 'package:flutter/material.dart';

class Skeleton extends StatefulWidget {
  final double height;
  final double width;
  final Color solidColor;
  final Color movingColor;
  final Duration interval;

  Skeleton({
    Key key,
    @required this.solidColor,
    @required this.movingColor,
    this.interval = const Duration(milliseconds: 1500),
    this.height = 20,
    this.width = 200,
  }) : super(key: key);

  createState() => SkeletonState();
}

class SkeletonState extends State<Skeleton>
    with SingleTickerProviderStateMixin {
  AnimationController _controller;

  Animation gradientPosition;

  @override
  void initState() {
    super.initState();
    _controller = AnimationController(
        duration: widget.interval, vsync: this);

    gradientPosition = Tween<double>(
      begin: -3,
      end: 10,
    ).animate(
      CurvedAnimation(parent: _controller, curve: Curves.linear),
    )..addListener(() {
        setState(() {});
      });

    _controller.repeat();
  }

  @override
  void dispose() {
    super.dispose();
    _controller.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: widget.width,
      height: widget.height,
      decoration: BoxDecoration(
        gradient: LinearGradient(
          begin: Alignment(gradientPosition.value, 1),
          end: Alignment(-1, -1),

          colors: [
            widget.solidColor,
            widget.solidColor,
            widget.movingColor,
            widget.solidColor,
            widget.solidColor,
          ],
          stops: [0.0, 0.35, 0.5, 0.65, 1.0],
        ),
      ),
    );
  }
}

==> skeleton-0.9.25.tar.gz: lib/skeleton.dart <==
import 'package:flutter/material.dart';

class Skeleton extends StatefulWidget {
  final double height;
  final double width;
  final Color solidColor;
  final Color movingColor;
  final Duration interval;

  Skeleton({
    Key key,
    @required this.solidColor,
    @required this.movingColor,
    this.interval = const Duration(milliseconds: 1500),
    this.height = 20,
    this.width = 200,
  }) : super(key: key);

  createState() => SkeletonState();
}

class SkeletonState extends State<Skeleton>
    with SingleTickerProviderStateMixin {
  AnimationController _controller;

  Animation gradientPosition;

  @override
  void initState() {
    super.initState();
    _controller = AnimationController(
        duration: widget.interval, vsync: this);

    gradientPosition = Tween<double>(
      begin: -3,
      end: 10,
    ).animate(
      CurvedAnimation(parent: _controller, curve: Curves.linear),
    )..addListener(() {
        setState(() {});
      });

    _controller.repeat();
  }

  @override
  void dispose() {
    super.dispose();
    _controller.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: widget.width,
      height: widget.height,
      decoration: BoxDecoration(
        gradient: LinearGradient(
          begin: Alignment(gradientPosition.value, 0.5),
          end: Alignment(-1, 0.5),

          colors: [
            widget.solidColor,
            widget.solidColor,
            widget.movingColor,
            widget.solidColor,
            widget.solidColor,
          ],
          stops: [0.0, 0.35, 0.5, 0.65, 1.0],
        ),
      ),
    );
  }
}
